@@ -1,4 +1,4 @@
-#' Reverse geocoding API for OSM elements in \CRANpkg{sf} format
+#' Reverse geocoding API in \CRANpkg{sf} format
 #'
 #' @description
 #'
@@ -162,7 +162,7 @@ reverse_geo_lite_sf <- function(lat,
     ))
 
     # Select rows
-    all_res <- all_res[as.integer(getrows$rindex), ]
+    all_res <- all_res[as.double(getrows$rindex), ]
   }
 
   # Final cleanup
