@@ -1,9 +1,9 @@
 list(
   rd_family_title = list(
     lookup = "Address Lookup API: ",
-    geocoding = "Geocoding strings: ",
+    geocoding = "Geocoding: ",
     reverse = "Reverse geocoding coordinates: ",
-    spatial = "Get \\CRANpkg{sf} objects: ",
+    spatial = "Get \\code{\\link[sf:sf]{sf}} objects: ",
     api_management = "API Management: "
   )
 )
